Hi, Raphael

On 7/29/2014 9:27 PM, Raphael Poggi wrote:
Some nand with 8k page size like Micron MT29F32G08ABAAAWP need more than 20us.

Signed-off-by: Raphaƫl Poggi <poggi.r...@gmail.com>
---
  drivers/mtd/nand/atmel_nand.c |    2 +-
  1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/mtd/nand/atmel_nand.c b/drivers/mtd/nand/atmel_nand.c
index e321c56..77bd877 100644
--- a/drivers/mtd/nand/atmel_nand.c
+++ b/drivers/mtd/nand/atmel_nand.c
@@ -2099,7 +2099,7 @@ static int atmel_nand_probe(struct platform_device *pdev)
        }
nand_chip->ecc.mode = host->board.ecc_mode;
-       nand_chip->chip_delay = 20;          /* 20us command delay time */
+       nand_chip->chip_delay = 40;          /* 40us command delay time */
if (host->board.bus_width_16) /* 16-bit bus width */
                nand_chip->options |= NAND_BUSWIDTH_16;

I just post a patch [1] days ago which does almost the same thing to support 4k-page nand flash.
personally I am fine with your patch.

Brain, you only need to take care this patch. And drop my patch [1].

[1] http://patchwork.ozlabs.org/patch/372406/

Thanks.
Best Regards,
Josh Wu


--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to